/***********************************************************
 * Hajime no Ippo --- file : hjime.cpp
 ***********************************************************/
#include <ode/ode.h>
#include <drawstuff/drawstuff.h>

static dWorldID world; // $B@$3&(BID
static dBodyID box;    // $B9dBN(BID
dReal  box_sizes[3] = { 1.0, 1.0, 1.0 };
                       // $B9dBN$N%5%$%:(B

#ifdef dDOUBLE
  #define dsDrawBox dsDrawBoxD
#endif

// start simulation - set viewpoint
static void start()
{
  static float xyz[3] = { 0.f, 5.f, 3.f };
  static float hpr[3] = { -90.f, -15.f, 0.f };

  dsSetViewpoint( xyz, hpr ); // $B%+%a%i0LCV$HJ}8~@_Dj(B
}

// simulation loop
static void simLoop( int pause )
{
  // Ctl+p $B$,2!$5$l$?$i(Bif$B$KF~$i$J$$(B
  if (!pause)
  {
    dWorldStep( world, 0.01 ); // $B@$3&$r?J$a$k(B
  }

  // $B9dBN$NI=<((B
  dsSetColor( 1, 1, 0 ); // RGB Color
  dsDrawBox( dBodyGetPosition( box ),
             dBodyGetRotation( box ),
             box_sizes );
}


int main( int argc, char* argv[] )
{
  // setup pointers to drawstuff callback functions
  dsFunctions fn;
  fn.version = DS_VERSION;
  fn.start   = &start;
  fn.step    = &simLoop;
  fn.command = 0;
  fn.stop    = 0;
  fn.path_to_textures = "../drawstuff/textures";

  world = dWorldCreate();         // $B@$3&@8@.(B
  //dWorldSetGravity( world, 0.0, 0.0, -9.8 );
                                  // $B@$3&$K=ENO$r@8@.(B(z$BJ}8~$K(B-9.8m/s/s)

  box = dBodyCreate( world );     // $B@$3&$K9dBN$r:n@.(B
  dReal pos[3] = { 0.0, 0.0, 3.0 };
  dBodySetPosition( box, pos[0], pos[1], pos[2] );
                                  // $B9dBN$N0LCV$r@_Dj(B

  dsSimulationLoop( argc, argv, 320, 240, &fn );
                                  // $B%7%_%e%l!<%7%g%s3+;O(B(simLoop$B$X(B)
                                  // + $B%&%#%s%I%&%5%$%:@_Dj(B

  dWorldDestroy( world );         // $B@$3&$NGK2u(B
  return 0;
}

